.. _supported-versions:

Supported versions
==================

``django-guardian`` supports Python 2.6+/3.3+ and Django 1.3+. Also, we support
``django-grappelli`` 2.3.5.

.. note::
   ``django-grappelli`` support was an experiment. We are not going to maintain
   this support starting with version 1.2. It means that since v1.2 grappelli
   parts within guardian would be deprecated. And removed before next big
   release (which most probably would be 2.0).

Rules
-----

* We would support Python 2.7 and Python 2.6 (until Django drops support for
  2.6). Since Django 1.5 we also support Python 3.3+.
* We support Django 1.3+, however next big ``guardian`` release (v2.0) we would
  support Django 1.6+ (or higher, depending on the date guardian v2.0 would be
  released). This is due to many simplifications in code we could do. There is
  also a chance that v2.0 would drop support for Python 2.X.

